# @summary Sets defaults based on OS
#
# @api private
class nrpe::params {

  $nrpe_provider = fact('os.family') ? {
    'Solaris' => pkgutil,
    default   => undef,
  }

  $nrpe_files_group = fact('os.family') ? {
    /(Free|Open)BSD/ => 'wheel',
    default          => 'root',
  }

  $nrpe_plugin_file_mode = '0755'

  case fact('os.family') {
    'Debian':  {
      $libdir           = '/usr/lib/nagios/plugins'
      $nrpe_user        = 'nagios'
      $nrpe_group       = 'nagios'
      $nrpe_pid_file    = '/var/run/nagios/nrpe.pid'
      $nrpe_config      = '/etc/nagios/nrpe.cfg'
      $nrpe_ssl_dir     = '/etc/nagios/nrpe-ssl'
      $nrpe_include_dir = '/etc/nagios/nrpe.d'
      $nrpe_service     = 'nagios-nrpe-server'
      $nrpe_packages    = [
        'nagios-nrpe-server',
        'nagios-plugins',
      ]
    }
    'Solaris': {
      $libdir           = '/opt/csw/libexec/nagios-plugins'
      $nrpe_user        = 'nagios'
      $nrpe_group       = 'nagios'
      $nrpe_pid_file    = '/var/run/nrpe.pid'
      $nrpe_config      = '/etc/opt/csw/nrpe.cfg'
      $nrpe_ssl_dir     = '/etc/opt/csw/nrpe-ssl'
      $nrpe_include_dir = '/etc/opt/csw/nrpe.d'
      $nrpe_service     = 'cswnrpe'
      $nrpe_packages    = [
        'nrpe',
        'nagios_plugins',
      ]
    }
    'RedHat':  {
      $libdir           = fact('os.architecture') ? {
        /x86_64/ => '/usr/lib64/nagios/plugins',
        default  => '/usr/lib/nagios/plugins',
      }
      $nrpe_user        = 'nrpe'
      $nrpe_group       = 'nrpe'
      $nrpe_pid_file    = '/var/run/nrpe/nrpe.pid'
      $nrpe_config      = '/etc/nagios/nrpe.cfg'
      $nrpe_ssl_dir     = '/etc/nagios/nrpe-ssl'
      $nrpe_include_dir = '/etc/nrpe.d'
      $nrpe_service     = 'nrpe'
      $nrpe_packages    = [
        'nrpe',
        'nagios-plugins-all',
      ]
    }
    'FreeBSD': {
      $libdir           = '/usr/local/libexec/nagios'
      $nrpe_user        = 'nagios'
      $nrpe_group       = 'nagios'
      $nrpe_pid_file    = '/var/run/nrpe2/nrpe2.pid'
      $nrpe_config      = '/usr/local/etc/nrpe.cfg'
      $nrpe_ssl_dir     = '/usr/local/etc/nrpe-ssl'
      $nrpe_include_dir = '/usr/local/etc/nrpe.d'
      $nrpe_service     = 'nrpe2'
      $nrpe_packages    = [
        'net-mgmt/nrpe',
        'net-mgmt/nagios-plugins',
      ]
    }
    'OpenBSD': {
      $libdir           = '/usr/local/libexec/nagios'
      $nrpe_user        = '_nrpe'
      $nrpe_group       = '_nrpe'
      $nrpe_pid_file    = '/var/run/nrpe/nrpe.pid'
      $nrpe_config      = '/etc/nrpe.cfg'
      $nrpe_ssl_dir     = '/etc/nrpe-ssl'
      $nrpe_include_dir = '/etc/nrpe.d'
      $nrpe_service     = 'nrpe'
      $nrpe_packages    = [
        'nrpe',
        'monitoring-plugins',
      ]
    }
    'Suse':  {
      $libdir           = '/usr/lib/nagios/plugins'
      $nrpe_user        = 'nagios'
      $nrpe_group       = 'nagios'
      $nrpe_pid_file    = '/var/run/nrpe/nrpe.pid'
      $nrpe_service     = 'nrpe'
      case fact('os.name') {
        'SLES': {
          $nrpe_config      = '/etc/nagios/nrpe.cfg'
          $nrpe_ssl_dir     = '/etc/nagios/nrpe-ssl'
          $nrpe_include_dir = '/etc/nagios/nrpe.d'
          $nrpe_packages    = [
            'nagios-nrpe',
            'nagios-plugins',
            'nagios-plugins-nrpe',
          ]
        }
        default:   {
          $nrpe_config      = '/etc/nrpe.cfg'
          $nrpe_ssl_dir     = '/etc/nrpe-ssl'
          $nrpe_include_dir = '/etc/nrpe.d'
          $nrpe_packages    = [
            'nrpe',
            'nagios-plugins-all',
          ]
        }
      }
    }
    'Gentoo':  {
      $libdir           = fact('os.architecture') ? {
        /x86_64/ => '/usr/lib64/nagios/plugins',
        default  => '/usr/lib/nagios/plugins',
      }
      $nrpe_user        = 'nagios'
      $nrpe_group       = 'nagios'
      $nrpe_pid_file    = '/var/run/nrpe.pid'
      $nrpe_config      = '/etc/nagios/nrpe.cfg'
      $nrpe_ssl_dir     = '/etc/nagios/nrpe-ssl'
      $nrpe_include_dir = '/etc/nagios/nrpe.d'
      $nrpe_service     = 'nrpe'
      $nrpe_packages    = [
        'net-analyzer/nrpe',
        'net-analyzer/nagios-plugins',
      ]
    }
    default:   {
    }
  }

  $dont_blame_nrpe                 = false
  $allow_bash_command_substitution = undef # not in very old NRPE
  $log_facility                    = 'daemon'
  $server_port                     = 5666
  $command_prefix                  = undef
  $debug                           = false
  $connection_timeout              = 300
  $allow_weak_random_seed          = true

  $ssl_version                 = 'TLSv1.2+'
  $ssl_ciphers                 = [
    'DHE-RSA-AES128-GCM-SHA256',
    'DHE-RSA-AES256-GCM-SHA384',
    'DHE-RSA-AES128-SHA',
    'DHE-RSA-AES256-SHA',
    'DHE-RSA-AES128-SHA256',
    'DHE-RSA-AES256-SHA256',
  ]
  $ssl_client_certs            = 'ask'
}
